#
# spec file for package lensfun
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sonum   1
Name:           lensfun
Version:        0.3.4
Release:        2.1
Summary:        A photographic lens database and a library for accessing it
License:        CC-BY-SA-3.0 AND LGPL-3.0-only
URL:            https://lensfun.github.io/
Source:         https://github.com/lensfun/lensfun/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
# updated lens database, use "osc service dr" to update it.
Source2:        data-master.tar.xz
BuildRequires:  cmake
BuildRequires:  doxygen
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  libpng-devel
BuildRequires:  pkgconfig
BuildRequires:  python-rpm-macros
BuildRequires:  python3
BuildRequires:  python3-docutils
BuildRequires:  python3-setuptools
BuildRequires:  zlib-devel
BuildRequires:  pkgconfig(glib-2.0)

%description
The goal of the lensfun library is to provide a open source database
of photographic lenses and their characteristics. In the past there
was a effort in this direction (see http://www.epaperpress.com/ptlens/),
but then author decided to take the commercial route and the database
froze at the last public stage. This database was used as the basement
on which lensfun database grew, thanks to PTLens author which gave his
permission for this, while the code was totally rewritten from scratch
(and the database was converted to a totally new, XML-based format).

The lensfun library not only provides a way to read the database and
search for specific things in it, but also provides a set of algorithms
for correcting images based on detailed knowledge of lens properties
and calibration data. Right now lensfun is designed to correct distortion,
transversal (also known as lateral) chromatic aberrations, vignetting
and colour contribution index of the lens.

%package data
Summary:        Data files for lensfun
BuildArch:      noarch

%description data
The goal of the lensfun library is to provide a open source database
of photographic lenses and their characteristics. In the past there
was a effort in this direction (see http://www.epaperpress.com/ptlens/),
but then author decided to take the commercial route and the database
froze at the last public stage. This database was used as the basement
on which lensfun database grew, thanks to PTLens author which gave his
permission for this, while the code was totally rewritten from scratch
(and the database was converted to a totally new, XML-based format).

The lensfun library not only provides a way to read the database and
search for specific things in it, but also provides a set of algorithms
for correcting images based on detailed knowledge of lens properties
and calibration data. Right now lensfun is designed to correct distortion,
transversal (also known as lateral) chromatic aberrations, vignetting
and colour contribution index of the lens.

%package -n liblensfun%{sonum}
Summary:        Library files for lensfun
Requires:       lensfun-data
Provides:       lensfun = %{version}
Obsoletes:      lensfun < %{version}

%description -n liblensfun%{sonum}
Library files needed by the use the lensfun library/database.

%package -n python3-lensfun
Summary:        Python3 lensfun bindings
Requires:       liblensfun%{sonum} = %{version}

%description -n python3-lensfun
Lensfun bindings for Python 3

%package tools
Summary:        Tools for managing lensfun data
Requires:       lensfun-data
Requires:       python3-lensfun = %{version}

%description tools
This package contains tools to fetch lens database updates and manage lens
adapters in lensfun.

%package doc
Summary:        Documentation for lensfun
Requires:       lensfun-data

%description doc
Documentation and manual files for the lensfun library/database.

%package devel
Summary:        Header and library definition files for lensfun
Requires:       lensfun-data = %{version}
Requires:       liblensfun%{sonum} = %{version}

%description devel
Header and library definition files for developing applications
that use the lensfun library/database.

%prep
%autosetup -p1 -a 2
echo 'HTML_TIMESTAMP=NO' >> docs/doxyfile.in.cmake
# fix python shebangs
sed -i \
    -e "s|^#!/usr/bin/env python3$|#!/usr/bin/python3|g" \
  apps/lensfun-add-adapter \
  apps/lensfun-update-data \
  apps/lensfun/__init__.py.in

sed -i 's#/usr/bin/env sh#/usr/bin/sh#' apps/g-lensfun-update-data

%build
%cmake \
    -DBUILD_LENSTOOL:BOOL=ON \
    -DBUILD_STATIC:BOOL=OFF \
    -DBUILD_TESTS:BOOL=ON \
    -DBUILD_DOC:BOOL=ON \
    -DCMAKE_INSTALL_DOCDIR:PATH=%{_defaultdocdir}/lensfun \
    -DINSTALL_HELPER_SCRIPTS:BOOL=ON \
    -DPYTHON_EXECUTABLE:STRING=python3

%cmake_build

%install
%cmake_install

pushd build/apps
python3 setup.py install --root="%{buildroot}" --skip-build
popd

# Unneeded
%if 0%{?suse_version} > 1500
rm %{buildroot}%{python3_sitelib}/lensfun-*.egg
%endif

# Create udate folder for lensfun data
mkdir -p %{buildroot}%{_localstatedir}/lib/lensfun-updates

%fdupes %{buildroot}
%python3_fix_shebang

%check
# ERROR: lensfun-0.3.4/tests/test_database.cpp:29:void test_DB_lens_search(lfFixture*, gconstpointer): 'lenses' should not be nullptr
%ifnarch %ix86 armv7hl
export LD_LIBRARY_PATH=%{buildroot}%{_libdir}${LD_LIBRARY_PATH:+:${LD_LIBRARY_PATH}}
%ctest
%endif

%ldconfig_scriptlets -n liblensfun%{sonum}

%files doc
%doc README.md
%doc docs/*
%doc %{_defaultdocdir}/lensfun

%files data
%{_datadir}/lensfun/
%dir %{_localstatedir}/lib/lensfun-updates/

%files -n liblensfun%{sonum}
%{_libdir}/*.so.*

%files -n python3-lensfun
%{python3_sitelib}/lensfun/
%{python3_sitelib}/lensfun-*.egg-info

%files devel
%{_includedir}/lensfun/
%{_libdir}/*.so
%{_libdir}/pkgconfig/lensfun.pc

%files tools
%{_bindir}/g-lensfun-update-data
%{_bindir}/lensfun-add-adapter
%{_bindir}/lensfun-update-data
%{_bindir}/lenstool
%{_mandir}/man?/g-lensfun-update-data*
%{_mandir}/man?/lensfun-add-adapter*
%{_mandir}/man?/lensfun-update-data*

%changelog
* Thu Apr 11 2024 pgajdos@suse.com
- remove dependency on /usr/bin/python3 using
  %%python3_fix_shebang macro, [bsc#1212476]
* Sat Jul 22 2023 Christophe Marin <christophe@krop.fr>
- Update to 0.3.4
  Check https://github.com/lensfun/lensfun/releases/tag/v0.3.4 for
  the list of new cameras and lenses supported.
  * Port apps/setup.py from Python distutils
  * CMake: Numerous backports from master
* Tue Mar  1 2022 Paolo Stivanin <info@paolostivanin.com>
- Update to 0.3.3:
  + Fixes:
  - Static lfXX::Create() and lfXX:Destroy() methods of various
    Lensfun classe are now marked as deprecated.
    C++ new/delete syntax should be used instead.
  - CMAKE: glib > 2.26 is now only required when tests are being build.
  - CMAKE: various fixes (paths, OS compatibility)
  + New cameras (https://github.com/lensfun/lensfun/releases/tag/v0.3.3)
  + New lenses (https://github.com/lensfun/lensfun/releases/tag/v0.3.3)
  + Updated data for lots of lenses
- Remove lensfun-respect-DESTDIR.patch
- Remove lensfun-test-database.patch
- Remove 0060-Various-CMake-patches-from-the-mailing-list.patch
- Remove lensfun_fix_memory_leak.patch
* Thu Jan  6 2022 Christophe Giboudeaux <christophe@krop.fr>
- Require python-rpm-macros for Leap 15.3
* Thu Apr  2 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update the license tag. The data files are under CC-BY-SA-3.0.
* Wed Apr  1 2020 Marcus Rueckert <mrueckert@suse.de>
- update lensfun data to 48775126:
  - Add Olympus OM-D E-M5 Mark III camera.
  - Add Olympus E-M1 Mark III
  - Build-Test failed - fix
  - commit 3f1289b44afb1b6f2ee22a8e87c7d1fb074be0f1 doubled entry
    for canon 15mm fisheye. Removed the one without data
  - Add 24-105mm f/3.5-5.6, 15mm f/2.8 Fisheye #1088
  - Improve Iphone XS profiles.
  - Move X100F from mil-fujifilm.xml
  - Move X100F to compact-fujifilm.xml
  - Add Iphone XS profiles contributed in #982
  - Merge pull request #1044 from EdgarLux/master
  - Add DC-S1 and DC-S1R per #1099
  - Add DMC-TZ96 per #1094
  - Added Canon EOS KISS M camera (it's actually the same as the
    Canon EOS M50, just a version of it released for the Japanese
    market)
  - data:lens: Improve TCA and vignetting for Sony FE 85mm f/1.4 GM
  - data:lens: Improve TCA and vignetting for Sony FE 16-35mm f/2.8
    GM
  - Upload 7471de #1072. Distortion and TCA corrections for Pentax
    HD PENTAX-DA 55-300mm f/4.5-6.3 ED PLM WR RE (×1,534).
  - Upload  3ed26e #479. Dostortion and TCA, Minolta AF 24-105mm
    f/3.5-4.5 (D).
  - Upload d4bd55 #478. Distortion and TCA for Minolta AF 17-35mm
    f/2.8-4 (D).
  - Upload fba583 #477. Minolta lens 50mm F1.4, distortion and TCA.
  - Upload 3a647c #1075. NIKKOR Z 24-70mm f2,8 S, distortion and
    TCA.
  - Upload 75f392 #476. Minolta AF 50mm f/2.8 Macro distortion and
    TCA.
  - The SM-N950U is the Galaxy Note 8
  - Add an alias for another name of the Samsung Galaxy S8
  - Upload 34eb2e #1047. Better correction for Leica 12-60mm µ4/3.
  - Upload 6180fa #468. Add TCA corrections for Canon PowerShot
    A640.
  - Upload 52e6be #465. Distortion and vignetting for Canon FD 50mm
    f/1.4 SCC.
  - Upload 5f1aab #454. Distortion and TCA corrections for Sony FE
    100-400 on full frame.
  - Upload cb3f38. New camera Canon Powershot SX50 HS with fixed
    lens. Distortion and TCA corrections for the lens. String
    corrections for SX60 HS for better automatic recognition.
  - Distortion & TCA data for the Panasonic Leica DG 10-25mm f/1.7
  - Add Sony E mount for Meike 35mm f/1.7
  - Added camera entry for Canon EOS EOS Rebel T6s
* Tue Mar 31 2020 Christophe Giboudeaux <christophe@krop.fr>
- Revert lensfun to 0.3.2. Git snapshots cause
  build and runtime issues in different packages (boo#1168150)
- Add patches back:
  * lensfun-respect-DESTDIR.patch
  * lensfun-test-database.patch
  * 0060-Various-CMake-patches-from-the-mailing-list.patch
  * lensfun_fix_memory_leak.patch
* Thu Mar 19 2020 info@paolostivanin.com
- Update to version v0.3.95.1584325617.48775126:
  * add support for lots of new cameras
  * add support for lots of new lenses
  * lots of bug fixes
- Remove 0060-Various-CMake-patches-from-the-mailing-list.patch
- Remove lensfun-respect-DESTDIR.patch
- Remove lensfun-test-database.patch
- Remove lensfun_fix_memory_leak.patch
* Mon Jan 13 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update the package URLs
* Thu Jan  2 2020 Adrian Schröter <adrian@suse.de>
- update lensdatabase to curent state (post 0.3.95)
* Wed Sep 11 2019 Adrian Schröter <adrian@suse.de>
- adapt to github hosting
- update lens database
* Thu Nov 30 2017 dimstar@opensuse.org
- Pass -DPYTHON_EXECUTABLE=%%{_bindir}/python3 to cmake: ensure the
  entire build uses python3.
* Tue Oct 24 2017 asn@cryptomilk.org
- Add lensfun_fix_memory_leak.patch to add a virtual destructor to
  avoid a memory leaks.
* Thu Jul 20 2017 wbauer@tmo.at
- Add 0060-Various-CMake-patches-from-the-mailing-list.patch (taken
  from Fedora) to only enable SSE/SSE2 on x86(_64), and only
  compile those files with -msse/-msse2 that have specific SSE(2)
  assembly code that's only used when SSE/SSE2 is actually
  available on runtime
- Don't set the BUILD_FOR_SSE(2) compile options at all, they were
  ON by default and above patch determines them automatically
  depending on the architecture
* Mon Jul 17 2017 tchvatal@suse.com
- Drop sse2 conditional, p4 is oldest supported by opensuse anyway
- Use %%cmake macros to produce the package instead of hand
  written approach
- Enable tests and add patch lensfun-test-database.patch
- Add patch lensfun-respect-DESTDIR.patch for py code to respect
  destdir
- Split tools to separate subpackage tools
- Install properly python3 bindings
* Thu May  5 2016 Mathias.Homann@opensuse.org
- update to version 0.3.2
    Incremented binary version number
    Improved vignetting interpolation
    Internal code cleanups
    Custom install directories can be configured by CMAKE_INSTALL_XXX variables (CMake GNUInstallDirs)
    New LENSFUN_WINDOWS_DATADIR CMake variable for better windows compatibility
    Support for parallel installation of different database versions
  New interchangeable lenses:
    Canon EF-S 10-18mm f/4.5-5.6 IS STM
    Canon EF-S 24mm f/2.8 STM
    Canon EF 24-70mm f/4L IS USM
    Canon FDn 50mm 1:1.8
    Canon FDn 24mm 1:2.8
    Contax G Planar T* 2/35
    Fujifilm XC 16-50mm f/3.5-5.6 OIS II
    Fujifilm XC 50-230mm f/4.5-6.7 OIS II
    Leica D Vario-Elmar 14-150mm f/3.5-5.6 Asph. OIS
    Minolta MD Rokkor 50mm 1:1.4
    1 Nikkor 18.5mm f/1.8
    1 Nikkor 32mm f/1.2
    Nikkor AF-S 20mm f/1.8G ED
    Nikon Lens Series E 28mm f/2.8
    Nikon Lens Series E 50mm f/1.8
    Nikkor AF-S 85mm f/1.4G
    Nikon Lens Series E 100mm f/2.8
    Nikkor AF 105mm f/2.8D Micro
    Nikkor AF-S 300mm f/4E PF ED VR
    Olympus M.Zuiko Digital ED 7-14mm f/2.8 Pro
    Olympus M.Zuiko Digital ED 8mm f/1.8 Fisheye Pro
    Olympus 9mm Body Cap Lens Fisheye
    Samyang 12mm f/2.8 Fish-Eye ED AS NCS
    Samyang 35mm T1.5 Cine Lens
    Sigma 70-300mm F4-5.6 DG Macro
    Sony FE 28mm f/2
    Sony FE 24-70mm f/4 ZA OSS
    Sony FE 55mm f/1.8 ZA
    Tamron 18-200mm f/3.5-6.3 Di III VC
    Tamron SP AF 70-200mm f/2.8 Di LD (IF) Macro
    Vivitar Series 1 70-210mm 1:3.5 SN 22...
    Voigtländer Ultron 40mm f/2 SL-II Aspherical
  New compact cameras:
    AEE MagiCam SD19 (action cam)
    Canon IXUS 125 HS
    Canon PowerShot G7 X
    Canon PowerShot S100
    Canon PowerShot S110
    Canon PowerShot SX130 IS
    Canon PowerShot SX510 HS
    GoPro HERO4 Silver
    LG G4
    Nikon Coolpix P7000
    Panasonic DMC-FZ150
    Panasonic DMC-LF1
    Panasonic DMC-TZ71
    Sony RX100 IV
  New interchangable lens cameras:
    Sony Alpha 7 II
    Sony Alpha 77 II
    Pentax K-3 II
    Pentax K-S1
    Pentax K-S2
    Samsung NX mini
  Additional/updated data for:
    Canon EF-S 18-135mm f/3.5-5.6 IS STM
    Canon EF 24mm f/2.8
    Canon EF 24-70mm f/2.8L USM
    Canon EF 50mm f/1.8 II
    Nikon AF-S Nikkor 18-135mm f/3.5-5.6G DX IF-ED
    Nikon AF-S Nikkor 20mm f/1.8G ED
    Nikon AF Nikkor 20mm f/2.8D
    Nikon AF-S Nikkor 50mm f/1.4G
    Nikon AF-S Nikkor 50mm f/1.8G
    Nikon AF-S Nikkor 28-300mm f/3.5-5.6G ED VR
    Nikon AF-S Zoom-Nikkor 16-35mm f/4G ED VR
    Nikon AF DX Fisheye-Nikkor 10.5mm f/2.8G ED
    Samsung NX 45mm f/1.8 2D/3D
    Sigma 12-24mm f/4.5-5.6 EX DG
    Sony DT 16-50mm f/2.8 SSM
    smc Pentax-A 28mm 1:2.8
    Sony FE 24-70mm f/4 ZA OSS
    Panasonic DMC-LX100
    Canon PowerShot G7 X
* Mon Aug  3 2015 mrueckert@suse.de
- update to version 0.3.1
  * Improved performance when used with 32-bit float image buffers.
  * Introduced automated testing.
  * lensfun-update-data now also works without root privileges
  * Fixed autoscaling for panoramic and equirectangular projections
  New interchangeable lenses:
  * Canon EF 16-35mm f/4L IS USM
  * Canon EF-S 18-55mm f/3.5-5.6 IS STM
  * Canon Lens FL 50mm F1.4
  * Canon FDn 50mm 1:1.4 (APS-C)
  * Nikkor AF-S 60mm f/2.8G ED Micro
  * Canon EF 70-210mm f/3.5-4.5 USM
  * Canon Lens FL 135mm F3.5
  * Canon EF 300mm f/2.8L IS II USM (also with 1.4x and 2.0x converters)
  * Canon EF 400mm f/5.6L USM (also with 1.4x converter)
  * Canon EF 500mm f/4L IS II USM (also with 1.4x and 2.0x converters)
  * Cosina 19-35mm f/3.5-4.5 MC
  * Fotasy M3517 35mm f/1.7
  * Fujifilm TCL-X100 teleconverter (for X100/X100s cameras)
  * Fujifilm XF 23mm f/1.4 R
  * Fujifilm XF 60mm f/2.4 R Macro
  * KMZ MC HELIOS-44M-4 58mm 1:2
  * Leica DG Summilux 15mm f/1.7
  * Lumix G Vario 12-32 f/3.5-5.6
  * Lumix G 14mm f/2.5 II
  * Minolta MD 35mm 1/2.8
  * Minolta AF 35-105mm f/3.5-4.5
  * Nikkor AF 10.5mm f/2.8G DX ED Fisheye
  * Nikkor AF-S 18-55mm f/3.5-5.6G DX VR II
  * Nikkor AF-S 18-300mm f/3.5-6.3G DX ED VR
  * Nikkor AI 20mm f/3.5
  * Nikkor AF 20-35mm f/2.8D IF
  * Nikkor AI-S 24mm f/2.8
  * Nikkor AF-S 24-120mm f/4G ED VR
  * Nikkor AF 28mm f/1.4D
  * Nikkor AF-S 28mm f/1.8G
  * Nikkor AI-S 28mm f/2.8
  * Nikkor AF 28-80mm f/3.3-5.6G
  * Nikkor AF 28-200mm f/3.5-5.6G IF-ED
  * Nikkor AI-S 35mm f/2.0
  * Nikkor AF 60mm f/2.8D Micro
  * Nikkor AF-S 70-300mm f/4.5-5.6G VR IF-ED
  * Olympus M.Zuiko Digital 60mm f/2.8 Macro
  * HD Pentax-DA 20-40mm f/2.8-4 ED Limited DC WR
  * smc Pentax-A 28mm 1:2.8
  * smc Pentax-DA 18-55mm f/3.5-5.6 AL II
  * smc Pentax-DA 50mm f/1.8
  * smc Pentax-M Macro 1:4 50mm
  * Ricoh 50mm 1:2.0
  * Schneider-Kreuznach Retina-Curtagon 1:4/28mm
  * Sigma 8mm f/3.5 EX DG Circular (APS-C)
  * Sony FE 28-70mm f/3.5-5.6 OSS
  * Tamron SP AF 60mm f/2 Di II LD (IF) Macro
  * Tamron SP 150-600mm f/5-6.3 Di VC USD
  * Tokina AF 100mm f/2.8 AT-X Pro D Macro
  * Voigtländer Skoparex 1:3,4/35
  * Voigtländer Color-Skopar X 1:2,8/50
  * Zenitar MC 16mm f/2.8
  * Carl Zeiss Jena 1Q Biotar 1:2 f=58mm T
  New interchangable lens cameras:
  * Canon EOS 7D Mark II
  * Canon EOS 750D
  * Canon EOS 760D
  * Canon EOS M2
  * Canon EOS M3
  * Fuji X-A2
  * Nikon D5500
  * Nikon D7200
  * Nikon 1 S2
  * Nikon 1 V3
  * Nikon 1 J5
  * Olympus E-5 Mark II
  * Panasonic DMC-GH4
  * Panasonic DMC-GF7
  * Samsung NX1
  * Samsung NX300M
  * Samsung NX500
  * Sony A5100
  New compact cameras:
  * Canon IXUS 220 HS (CHDK's DNGs)
  * Canon PowerShot A4000 IS (CHDK's DNGs)
  * Canon PowerShot G1 X Mark II
  * Canon PowerShot S95
  * DIJ Phantom Vision FC200
  * Fujifilm FinePix A370
  * Fujifilm X100T
  * Fujifilm X30
  * Fujifilm XQ1
  * Olympus E-PL7
  * Olympus Stylus 1s
  * Panasonic FZ1000
  * Panasonic DMC-GM5
  * Panasonic DMC-LX100
  * Ricoh GR
  * Sony RX100 III
  Additional/updated data for:
  * Canon EF-S 10-22mm f/3.5-4.5 USM
  * Canon TS-E 24mm f/3.5L
  * Canon EF 24-85mm f/3.5-4.5 USM
  * Canon EF 50mm f/1.8
  * Canon EF 70-200mm f/4L IS USM
  * Fujifilm XC 16-50mm f/3.5-5.6 OIS
  * Fujifilm XC 50-230mm f/4.5-6.7 OIS
  * Nikkor AF 24-85mm f/2.8-4D IF
  * Nikkor AF 50mm f/1.4D
  * Nikkor AF 50mm f/1.8D
  * Nikkor AF-S 55-300mm f/4.5-5.6G DX ED VR
  * Nikkor AF-S 70-200mm f/2.8G VR IF-ED
  * Nikkor AF 70-210mm f/4-5.6
  * Nikkor AF 80-200mm f/2.8 ED
  * Nikkor AF 85mm f/1.8
  * Olympus M.Zuiko Digital 25mm f/1.8
  * Olympus M.Zuiko Digital 60mm f/2.8 Macro
  * Olympus M.Zuiko Digital ED 75-300mm f/4.8-6.7 II
  * smc Pentax-DA 18-55mm f/3.5-5.6 AL WR
  * smc Pentax-M 28mm 1:3.5
  * smc Pentax-DA 35mm f/2.4 AL
  * smc Pentax-A 50mm f/1.7
  * Samyang 14mm f/2.8 ED AS IF UMC
  * Sigma 19mm f/2.8 EX DN
  * Sigma 50-150mm f/2.8 APO EX DC OS HSM
  * Sigma 70-200mm f/2.8 EX DG OS HSM
  * Sigma 105mm f/2.8 EX DG OS HSM Macro
  * Sony 50mm f/1.4
  * Sony E 16-50mm f/3.5-5.6 OSS PZ
  * Canon PowerShot A640
  * Canon PowerShot A720
  * Canon PowerShot SX150
  * Canon PowerShot SX220
* Wed Jul 15 2015 jengelh@inai.de
- Fixup RPM groups and incorrect buildrequires. Use simpler
  download URL. data does not hard-depend on shared library.
* Tue Feb 24 2015 adrian@suse.de
- update to version 0.3.0
  * Streamlined the names of Nikkor, Tamron, Tokina, Panasonic, Leica, Olympus,
    Sony, and Sigma lenses so that auto-detection works better
  * Fixed names of Sony Coolpix cameras
  * Comprehensive update of Lensfun's documentation
  * Lens lists may now be sorted by focal length
  * The <cropfactor> tag is now mandatory for <camera> and <lens> in the database files
  * Increased accuracy because APS-C is not anymore assumed to have the crop
    factor 1.5 (non-Canon) or 1.6 (Canon), but the accurate crop factor of the
    respective camera
  * Added command line tool "update-lensfun-data" for updating the database
  * Added command line tool "lensfun-add-adapter" for managing mount compatibilities
  * Removed compatibility of Four Third on Micro Four Third
  * Removed compatibility of Sony Alpha on Sony E
  * Many bugfixes, especially for the case if sensor sizes of calibration and
    image to-be-corrected are different
  * MaxAperture is now the maximal f-stop number one can set on the given lens
  * Removed non-working implementation of CCI
  * Made primary keys of the database tables explicit and documented
  * Replaced field-of-view data with real-focal-length data; marked the FOV API
    deprecated
  * Higher accuracy for fisheye <--> rectinilear transformation for lenses with
    real focal length data
  * The field-of-view distortion model (FOV1) was removed because it is
    inherently flawed
  * Simplified method for finding the database directories; see documentation
  * Removed old non-CMake build system
  * Added new cameras
  New interchangeable lenses:
  * Canon EF-S 15-85mm f/3.5-5.6 IS USM
  * Canon EF 16-35mm f/2.8L II USM
  * Canon EF-S 18-55mm f/3.5-5.6 IS
  * Canon EF-M 18-55mm f/3.5-5.6 IS STM
  * Canon EF-S 18-135mm f/3.5-5.6 IS STM
  * Canon EF-S 18-200mm f/3.5-5.6 IS
  * Canon EF-M 22mm f/2 STM
  * Canon EF 24-70mm f/2.8L II USM
  * Canon EF 28-80mm f/3.5-5.6 USM IV
  * Canon EF 50mm f/1.8 MkII
  * Canon EF 50-200mm f/3.5-4.5L
  * Canon EF-S 55-250mm f/4-5.6 IS
  * Canon EF 70-300mm f/4-5.6L IS USM
  * Cosina Cosinon-S 50mm 1:2
  * KMZ MC MTO 11CA mirror tele
  * Leica DG Macro-Elmarit 45mm f/2.8
  * Mitakon wide MC f=24mm 1:2.8
  * 1 Nikkor AW 11-27.5mm f/3.5-5.6
  * Nikkor AI-S 6mm f/2.8 Fisheye
  * Nikkor AF-S 18-140mm f/3.5-5.6G DX ED VR
  * Nikkor AF-S 18-200mm f/3.5-5.6G DX VR IF-ED
  * Nikkor AF-S 24-85 mm f/3.5-4.5G ED VR
  * Nikkor AI-S 50mm f/1.2
  * Nikkor AF-S 50mm f/1.8G
  * Nikkor AF-S 55-300mm f/4.5-5.6G DX ED VR
  * Nikkor AF-S 70-200mm f/4G VR IF-ED
  * Nikkor AF-S 70-300mm f/4.5-5.6G VR IF-ED
  * Nikkor AF-S VR 105mm f/2.8G IF-ED
  * Nikkor AF-S 600mm f/4G ED VR
  * Nikkor AF-S 800mm f/5.6E FL ED VR
  * Fujian 35mm f/1.7
  * Fujifilm XC 16-50mm f/3.5-5.6 OIS
  * Fujifilm XF 18mm f/2 R
  * Fujifilm XF 18-55mm f/2.8-4 R LM OIS
  * Fujifilm XF 27mm f/2.8
  * Fujifilm XF 35mm f/1.4 R
  * Fujifilm XC 50-230mm f/4.5-6.7 OIS
  * Fujifilm XF 55-200mm f/3.5-4.8 R LM OIS
  * Olympus M.9-18mm f/4.0-5.6
  * Olympus Zuiko Digital ED 12-60mm f/2.8-4.0 SWD
  * Olympus M.Zuiko Digital 25mm f/1.8
  * Olympus M.40-150mm f/4.0-5.6 R
  * Olympus M.Zuiko Digital ED 75mm f/1.8
  * Olympus M.Zuiko Digital 75-300mm f/4.8-6.7 II
  * Panasonic Lumix G Vario 7-14mm f/4.0
  * Panasonic Lumix G Vario 12-35mm f/2.8
  * Panasonic Lumix G Vario 14-42mm f/3.5-5.6 II
  * Panasonic Lumix G Vario 14-45mm f/3.5-5.6 Asph. Mega OIS
  * Panasonic Lumix G 20mm f/1.7 II
  * Panasonic Lumix G Vario 35-100mm f/2.8
  * Panasonic Lumix G Vario 45-150mm f/4.0-5.6
  * Panasonic Lumix G Vario PZ 45-175mm f/4.0-5.6
  * Pentacon 50mm f/1.8 auto multi coating
  * Pentax-DA Fish-Eye 10-17mm f/3.5-4.5 ED IF
  * Pentax-FA 28mm f/2.8 AL
  * Pentax-M 28mm 1:3.5
  * Pentax-FA 31mm F1.8 AL Limited
  * Pentax-M 35mm 1:2
  * Pentax-A 50mm f/1.7
  * Pentax-DA L 55-300mm f/4-5.8 ED
  * Ricoh XR Rikenon 1:1.4 50mm
  * Samyang 8mm f/3.5 Fish-Eye CS
  * Samyang T-S 24mm f/3.5 ED AS UMC
  * Samsung NX 16-50mm f/3.5-5.6 PZ ED OIS
  * Samsung Zoom 18-55mm f/3.5-5.6 OIS
  * Samsung NX 20mm f/2.8 Pancake
  * Samsung NX 45mm f/1.8 2D/3D
  * Samyang 12mm f/2.0 NCS CS
  * Samyang 35mm f/1.4 AS UMC
  * Samyang 50mm f/1.4 AS UMC (APS-C only)
  * Sigma 10mm f/2.8 EX DC Fisheye HSM
  * Sigma 18-35mm f/1.8 DC HSM
  * Sigma 18-250mm f/3.5-6.3 DC OS MACRO HSM
  * Sigma 24-70mm f/2.8 IF EX DG HSM
  * Sigma 24-105mm f/4.0 DG OS HSM [A]
  * Sigma 17-70mm f/2.8-4 DC Macro OS HSM
  * Sigma 19mm f/2.8 DN
  * Sigma 19mm f/2.8 EX DN
  * Sigma 30mm f/2.8 EX DN
  * Sigma 50mm f/1.4 DG HSM [A]
  * Sigma 50-150mm f/2.8 APO EX DC HSM II
  * Sigma 60mm f/2.8 DN
  * Sigma 70-200mm f/2.8 EX DG APO OS HSM
  * Sigma 70-200mm f/2.8 EX DG Macro HSM II
  * Sigma 80-400mm f/4.5-5.6 EX DG OS
  * Sigma 100-300mm f/4 APO EX DG HSM
  * Sigma 105mm f/2.8 EX DG OS HSM Macro
  * Sigma 180mm f/2.8 EX DG OS HSM APO Macro
  * Sigma 180mm f/5.6 APO Macro
  * Sony E 10-18mm f/4 OSS
  * Sony E 16-70mm f/4 ZA OSS
  * Sony E PZ 18-105mm f/4 G OSS
  * Sony DT 18-135mm f/3.5-5.6 SAM
  * Sony AF DT 35mm f/1.8 SAM
  * Sony AF DT 50mm f/1.8 SAM
  * Sony DT 55-300mm f/4.5-5.6 SAM
  * Tamron SP AF 11-18mm f/4.5-5.6 Di-II LD Aspherical (IF)
  * Tamron 16-300mm f/3.5-6.3 Di II VC PZD
  * Tamron 18-200mm f/3.5-6.3 XR Di II LD
  * Tokina AF 12-28mm f/4 AT-X Pro DX
  * Tokina AF 16-28mm f/2.8 AT-X Pro SD FX
  * Tokina 500mm f/8 RMC Mirror Lens
  * Vivitar 100mm f/3.5 AF Macro
  * Carl Zeiss Distagon T* 2,8/21 ZE
  * Carl Zeiss Distagon T* 2,8/21 ZF.2
  * Zeiss E 32mm f/1.8
  New compact cameras:
  * Canon PowerShot A640
  * Canon PowerShot A720
  * Canon PowerShot IXUS 70
  * Canon PowerShot S90
  * Canon PowerShot S120
  * Canon PowerShot SX220 HS
  * Canon PowerShot SX230 HS
  * Canon PowerShot SX260 HS
  * Fujifilm FinePix F770EXR
  * Fujifilm FinePix HS20EXR
  * Fujifilm FineFix S5600
  * Fujifilm X20
  * GoPro Hero HD2
  * Kodak CX6330
  * Nikon Coolpix S3300
  * Nokia Lumia 1020
  * Olympus Stylus 1
  * Panasonic Lumix DMC-LX7
  * Panasonic Lumix DMC-FZ200
  * Sony DSC-HX300
  * Sony RX100 II
  * Sony RX100 III
  Additional/updated data for:
  * Canon EF-S 18-55mm f/3.5-5.6 IS II
  * Canon EF 24-70mm f/2.8L II USM
  * Canon EF 24-105mm f/4L IS USM
  * Canon EF 50mm f/1.8 MkII
  * Canon EF 50-200mm f/3.5-4.5L
  * Canon EF 70-200mm f/2.8L IS II USM
  * Canon EF 70-200mm f/4L IS USM
  * Canon EF 85mm f/1.8 USM
  * Canon EF 100mm f/2.8L Macro IS USM
  * Nikkor AF-S 10-24mm f/3.5-4.5G DX ED
  * Nikkor AF-S 16-85mm f/3.5-5.6G DX ED VR
  * Nikkor AF-S 18-55mm f/3.5-5.6G DX VR
  * Nikkor AF-S 18-105mm f/3.5-5.6G DX ED VR
  * Nikkor AF-S 18-200mm f/3.5-5.6G DX VR IF-ED II
  * Nikkor AF 20mm f/2.8D
  * Nikkor AF-S 35mm f/1.8G DX
  * Nikkor AF-S 50mm f/1.4G
  * Nikkor AF-S 55-300mm f/4.5-5.6G DX ED VR
  * Olympus M.Zuiko Digital ED 14-42mm f/3.5-5.6 L
  * Olympus M.Zuiko Digital 17mm f/1.8
  * Panasonic Lumix G Vario 45-200mm f/4.0-5.6 Mega OIS
  * Pentax 01 Standard Prime 8.5 mm f/1.9 AL [IF]
  * Pentax-DA* 16-50mm f/2.8 ED AL IF SDM
  * Pentax-DA* 50-135mm f/2.8 ED IF SDM
  * Pentax-D FA Macro 100mm f/2.8 WR
  * Samyang 8mm f/2.8 Fisheye
  * Sigma 8-16mm F4.5-5.6 DC HSM
  * Sigma 10-20mm f/3.5 EX DC HSM
  * Sigma 10-20mm f/4-5.6 EX DC HSM
  * Sigma 15-30mm f/3.5-4.5 EX DG Aspherical
  * Sigma 30mm f/1.4 EX DC HSM
  * Sigma 35mm f/1.4 DG HSM
  * Sigma 50mm f/1.4 EX DG HSM
  * Sigma 70-200mm f/2.8 EX DG Macro HSM II
  * Sigma 150mm f/2.8 EX DG APO HSM Macro
  * Sony RX100
  * Sony DT 18-55mm f/3.5-5.6 SAM
  * Sony E 20mm f/2.8
  * Sony AF DT 55-200mm f/4-5.6 SAM
  * Panasonic Lumix G Vario 14-42 f/3.5-5.6 II
  * Panasonic Lumix G X Vario PZ 14-42 f/3.5-5.6
  * Tamron SP AF 17-50mm f/2.8
* Wed Jun 11 2014 adrian@suse.de
- update URLs to new home on sourceforge
- update to version 0.2.8, new support for following lenses:
    Canon EF-S 60mm f/2.8 Macro
    Canon EF-S 18-135mm f/3.5-5.6 IS
    Canon EF 100mm f/2.8L Macro IS USM
    Canon EF 200mm f/2.8L USM
    Canon EF 85mm f/1.2L II USM
    Canon EF 50mm f/1.2L USM
    Canon EF 70-200mm f/2.8L USM
    Canon EF 70-200mm f/2.8L IS II USM
    Canon FDn 100mm 1:2.8
    Canon FDn 50mm 1:1.4
    Nikkor 24-70mm f/2.8G ED
    Nikon AF-S DX VR Zoom-Nikkor 18-55mm f/3.5-5.6G
    Nikon AF-S DX Zoom-Nikkor 18-70mm f/3.5-4.5G IF-ED
    Nikon AF-S Zoom-Nikkor 14-24mm f/2.8G ED
    Nikon AF-S Nikkor 85mm f/1.8G
    Zuiko Digital 25mm F2.8
    Zuiko Digital 35mm f/3.5 Macro
    Zuiko Digital ED 14-42mm F3.5-5.6
    Zuiko Digital ED 40-150mm F4.0-5.6
    Zuiko Digital ED 9-18mm F4.0-5.6
    smc PENTAX-D FA Macro 100mm F2.8 WR
    smc PENTAX-DA 15mm F4 ED AL Limited
    smc PENTAX-DA 18-55mm F3.5-5.6 AL WR
    smc PENTAX-DA 21mm f/3.2 AL Limited
    smc PENTAX-DA 35mm f/2.4 AL
    smc PENTAX-FA 43mm F1.9 Limited
    smc PENTAX-FA 50mm f/1.4
    smc PENTAX-DA* 50-135mm f/2.8 ED [IF] SDM
    SIGMA 8mm f/3.5 EX DG Circular
    SIGMA 8-16mm f/4.5-5.6mm DC HSM
    SIGMA 10-20mm F4-5.6 EX DC HSM
    SIGMA 17-50mm F2.8 EX DC OS HSM
    SIGMA 24-60mm F2.8 EX DG
    SIGMA E 30mm F2.8
    SIGMA 35mm f/1.4 DG HSM
    SIGMA 150mm F2.8 MACRO HSM
    SIGMA 150-500mm f/5-6.3 APO DG OS HSM
    OLYMPUS M.14-150mm F4.0-5.6
    OLYMPUS M.17mm F1.8
    OLYMPUS M.45mm F1.8
    Leica DG Summilux 25/f1.4
    LUMIX G 14/F2.5 + GWC1 0.79x
    LUMIX G VARIO PZ 14-42/F3.5-5.6
    Samsung 16mm f/2.4
    Samyang 7.5mm F/3.5 UMC Fish-eye MFT
    Samyang 8mm f/2.8 UMC Fish-eye
    Samyang 14mm f/2.8 ED AS IF UMC
    Samyang 500mm f/6.3 MC IF Mirror Lens
    Sony E 10-18mm F4 OSS
    Sony E PZ 16-50mm F3.5-5.6 OS
    Sony E 18-200mm F3.5-6.3 OSS
    Sony E 18-200mm F3.5-6.3 OSS LE
    Sony E 30mm F3.5 Macro
    Sony E 35mm F1.8 OSS
    Sony DT 16-50mm F2.8 SSM
    Tamron AF 18-270mm f/3.5-6.3 Di II VC PZD
    Tamron SP AF 90mm f/2.8 (172E)
    Compact cameras:
    Canon PowerShot G11
    Canon PowerShot G1X
    Canon PowerShot SX150 IS
    Fujifilm X10
    Fujifilm X100S
    Panasonic DMC-FZ28
    Panasonic LX7
    SAMSUNG WB2000 compact camera
    Sigma DP2
* Wed Jun 11 2014 adrian@suse.de
- update URLs to new home on sourceforge
- update to version 0.2.8, new support for following lenses:
    Canon EF-S 60mm f/2.8 Macro
    Canon EF-S 18-135mm f/3.5-5.6 IS
    Canon EF 100mm f/2.8L Macro IS USM
    Canon EF 200mm f/2.8L USM
    Canon EF 85mm f/1.2L II USM
    Canon EF 50mm f/1.2L USM
    Canon EF 70-200mm f/2.8L USM
    Canon EF 70-200mm f/2.8L IS II USM
    Canon FDn 100mm 1:2.8
    Canon FDn 50mm 1:1.4
    Nikkor 24-70mm f/2.8G ED
    Nikon AF-S DX VR Zoom-Nikkor 18-55mm f/3.5-5.6G
    Nikon AF-S DX Zoom-Nikkor 18-70mm f/3.5-4.5G IF-ED
    Nikon AF-S Zoom-Nikkor 14-24mm f/2.8G ED
    Nikon AF-S Nikkor 85mm f/1.8G
    Zuiko Digital 25mm F2.8
    Zuiko Digital 35mm f/3.5 Macro
    Zuiko Digital ED 14-42mm F3.5-5.6
    Zuiko Digital ED 40-150mm F4.0-5.6
    Zuiko Digital ED 9-18mm F4.0-5.6
    smc PENTAX-D FA Macro 100mm F2.8 WR
    smc PENTAX-DA 15mm F4 ED AL Limited
    smc PENTAX-DA 18-55mm F3.5-5.6 AL WR
    smc PENTAX-DA 21mm f/3.2 AL Limited
    smc PENTAX-DA 35mm f/2.4 AL
    smc PENTAX-FA 43mm F1.9 Limited
    smc PENTAX-FA 50mm f/1.4
    smc PENTAX-DA* 50-135mm f/2.8 ED [IF] SDM
    SIGMA 8mm f/3.5 EX DG Circular
    SIGMA 8-16mm f/4.5-5.6mm DC HSM
    SIGMA 10-20mm F4-5.6 EX DC HSM
    SIGMA 17-50mm F2.8 EX DC OS HSM
    SIGMA 24-60mm F2.8 EX DG
    SIGMA E 30mm F2.8
    SIGMA 35mm f/1.4 DG HSM
    SIGMA 150mm F2.8 MACRO HSM
    SIGMA 150-500mm f/5-6.3 APO DG OS HSM
    OLYMPUS M.14-150mm F4.0-5.6
    OLYMPUS M.17mm F1.8
    OLYMPUS M.45mm F1.8
    Leica DG Summilux 25/f1.4
    LUMIX G 14/F2.5 + GWC1 0.79x
    LUMIX G VARIO PZ 14-42/F3.5-5.6
    Samsung 16mm f/2.4
    Samyang 7.5mm F/3.5 UMC Fish-eye MFT
    Samyang 8mm f/2.8 UMC Fish-eye
    Samyang 14mm f/2.8 ED AS IF UMC
    Samyang 500mm f/6.3 MC IF Mirror Lens
    Sony E 10-18mm F4 OSS
    Sony E PZ 16-50mm F3.5-5.6 OS
    Sony E 18-200mm F3.5-6.3 OSS
    Sony E 18-200mm F3.5-6.3 OSS LE
    Sony E 30mm F3.5 Macro
    Sony E 35mm F1.8 OSS
    Sony DT 16-50mm F2.8 SSM
    Tamron AF 18-270mm f/3.5-6.3 Di II VC PZD
    Tamron SP AF 90mm f/2.8 (172E)
    Compact cameras:
    Canon PowerShot G11
    Canon PowerShot G1X
    Canon PowerShot SX150 IS
    Fujifilm X10
    Fujifilm X100S
    Panasonic DMC-FZ28
    Panasonic LX7
    SAMSUNG WB2000 compact camera
    Sigma DP2
* Tue May 27 2014 crrodriguez@opensuse.org
- Tell doxygen to stop creating files with timestamps to
  avoid endless republish.
* Fri Mar 22 2013 idonmez@suse.com
- Fix build for PPC64
* Mon Mar  4 2013 salsergey@gmail.com
- Update to version 0.2.7:
  * Some bugs leading to imprecise results when processing extreme
    values were fixed.
  * Several new lenses and camera profiles.
- Revised installed documentation.
- lens_database_update.diff removed because no new lenses were
  added to the database after 0.2.7 release. The mention of this
  patch in spec file remains.
- lens_database_pending_update.diff removed because these chages
  were commited upstream.
* Wed Aug 22 2012 fcrozat@suse.com
- Update lens data for Nikon.
- Add lens_database_pending_update.diff: pending lens data update
  for Canon and Samsung.
* Wed Jun 27 2012 adrian@suse.de
- update to version 0.2.6
  - minor database updates
  - better integration into hugin for loading and storing lens
    parameters via the lensfun library
  - several bug fixes and stability improvements
  - pkgconfig got dropped
- used optimization depends not on build host anymore.
  (This avoids crashes on ix86)
* Wed Apr 25 2012 adrian@suse.de
- update lens data for Sony, Olympus and Pentax
* Thu Apr 19 2012 dmueller@suse.com
- fix build for older distros
* Tue Dec 20 2011 dmueller@suse.de
- fix build on arm
* Mon Nov 14 2011 adrian@suse.de
- update lens database
* Fri Oct  7 2011 toddrme2178@gmail.com
- Added provides for obsoletes (fix for RPMLINT warning)
- Cleaned up spec file formatting
* Wed Aug 24 2011 adrian@suse.de
- add Obsolete for package rename
- update lensfun database to current state
* Sun Aug  7 2011 toddrme2178@gmail.com
- Switched contents of lensun to noarch lensfun-data package
- Cleaned up some macros and the %%files list
* Mon Jun 27 2011 toddrme2178@gmail.com
- Clarified summaries and descriptions (fix for RPMLINT warnings)
* Mon Jun 20 2011 coolo@novell.com
- remove download_url service
* Mon Jun 13 2011 fcrozat@suse.com
- Add lensfun-fixcrash.patch: fix crash on malformed database (SVN)
- Add lensfun-0.2.5-cpuid.patch: fix crash on cpu detection (SVN)
- set GCC.LDFLAGS to avoid stripping and useless -debug* package.
* Sat Apr  9 2011 meissner@suse.de
- disable vectorization on ppc (not supported by lensfun yet)
* Sat Jan  8 2011 adrian@suse.de
- update lens database to last years additions
* Wed Nov 10 2010 adrian@suse.de
- update to version 0.2.5 (bug #652480)
  * Bugfixes in library
  * New TCA correction algorithm: LF_TCA_MODEL_POLY3
- Move documentation to official place
* Sun Jan 17 2010 tittiatcoke@gmail.com
- Initial package
